# CSS Logical Properties and Values Level 1

## Editor’s Draft, 1 January 1970

Specification Metadata

This version:
  https://drafts.csswg.org/css-logical-1/
Latest published version:
  https://www.w3.org/TR/css-logical-1/
Previous Versions:
  https://www.w3.org/TR/2017/WD-css-logical-1-20170518/
Editors:
  Rossen Atanassov (Microsoft)
  Elika J. Etemad / fantasai (Invited Expert)
Issue Tracking:
  GitHub Issues
Suggest an Edit for this Spec:
  GitHub Editor

Copyright © 1970 W3C® (MIT, ERCIM, Keio, Beihang). W3C liability, trademark and permissive document license rules apply.

## Abstract

This module introduces logical properties and values that provide the author with the ability to control layout through logical, rather than physical, direction and dimension mappings. The module defines logical properties and values for the features defined in [CSS21]. These properties are writing-mode relative equivalents of their corresponding physical properties.

CSS is a language for describing the rendering of structured documents (such as HTML and XML) on screen, on paper, etc.

## Status of this document

This is a public copy of the editors’ draft. It is provided for discussion only and may change at any moment. Its publication here does not imply endorsement of its contents by W3C. Don’t cite this document other than as work in progress.

GitHub Issues are preferred for discussion of this specification. When filing an issue, please put the text “css-logical” in the title, preferably like this: “[css-logical] …summary of comment…”. All issues and comments are archived, and there is also a historical archive.

This document was produced by the CSS Working Group.

This document was produced by a group operating under the W3C Patent Policy. W3C maintains a public list of any patent disclosures made in connection with the deliverables of the group; that page also includes instructions for disclosing a patent. An individual who has actual knowledge of a patent which the individual believes contains Essential Claim(s) must disclose the information in accordance with section 6 of the W3C Patent Policy.

This document is governed by the 1 March 2019 W3C Process Document.

## 1. Introduction

Note: See [css-writing-modes-4] for a proper introduction to writing modes; this module assumes familiarity with its terminology.

Because different writing systems are written in different directions, a variety of writing modes exist: left to right, top to bottom; right to left, top to bottom; bottom to top, right to left; etc. logical concepts like the “start” of a page or line map differently to physical concepts like the “top” of a line or “left edge” of a paragraph. Some aspects of a layout are actually relative to the writing directions, and thus will vary when the page is translated to a different system; others are inherently relative to the page’s physical orientation.

For example, lists, headings, and paragraphs are typically left-aligned in English; but actually they are start-aligned, because in Arabic the same constructs are right-aligned, and a multilingual document will need to accommodate both writing systems accordingly.

The following code examplify how using logical syntax can help you write code that works across different writing systems:

Rendering of the below code in a compatible browser

    <blockquote dir="auto">Quotation in English</blockquote>
    <blockquote dir="auto">اقتباس في العربية</blockquote>

    blockquote {
        text-align: start; /* left in latin, right in arabic */
        margin-inline-start: 0px; /* margin-left in latin, margin-right in arabic */
        border-inline-start: 5px solid gray; /* border-left in latin, border-right in arabic */
        padding-inline-start: 5px; /* padding-left in latin, padding-right in arabic */
    }

Documents might need both logical and physical properties. For instance the drop shadows on buttons on a page must remain consistent throughout, so their offset will be chosen based on visual considerations and physical directions, and not vary by writing system.

Since CSS was originally designed with only physical coordinates in its controls, this module introduces text-flow–relative equivalents so that declarations in a CSS style sheet can be expressed in flow-relative terms. It defines the mapping and cascading of equivalent properties, some new properties and values equivalent to those in CSS2.1, and the principles used to derive their syntaxes. Future CSS specifications are expected to incorporate both sets of coordinates in their property and value definitions, so this module will not track the introduction of flow-relative variants of newer CSS features.

CSS Writing Modes’ Abstract Box Terminology section defines how to map between flow-relative and physical terms. This mapping, which depends on the used values of writing-mode and direction, controls the interpretation of flow-relative keywords and properties.

Correspondence of physical and flow-relative terms in typical English text layout
Correspondence of physical and flow-relative terms in typical Chinese text layout

Note: Due to its interaction with text-orientation: upright, the used direction depends on the computed values of writing-mode and text-orientation.

Things That Are Unstable Since implementation of parts of this module is effectively required for shipping an implementation of CSS Writing Modes on the Web (in order to correctly implement the default HTML styles), the CSSWG resolved that the requisite features in § 2 Flow-Relative Values: block-start, block-end, inline-start, inline-end and § 4 Flow-Relative Box Model Properties are approved for shipping. (See FPWD announcement for additional background.)

However, there are a few significant open issues:

- The logical keyword on shorthands, because the name of the keyword may change or it may be replaced by some other syntactic marker. (This feature will be deferred from this level for further development if there is no clearly satisfactory mechanism proposed, see Issue 1282.)
- Whether flow-relative longhands inherit from their namesake on the parent, or are mapped to a physical property and inherit from that property. (See Issue 3029.)
- Whether shorthands like margin expand to both sets of longhands, or only the ones that were set. (See Issue 3030.)

Comments, suggestions, and use cases are welcome on these issues. Please file them in GitHub, tweet them to @csswg, or send them to www-style@w3.org.

## 2. Flow-Relative Values: block-start, block-end, inline-start, inline-end

Properties that accept physical directional keyword values (top, bottom, left, or right) are redefined to also accept the appropriate flow-relative directional keywords. In such cases, the flow-relative values can be used in place of the corresponding physical values. For properties that take multiple keywords, combinations of flow-relative and physical values are not allowed (unless otherwise specified in a future specification).

Properties can be either 1-dimensional or 2-dimensional. When contextually constrained to one dimension, the flow-relative keywords are abbreviated.

### 2.1. Logical Values for the caption-side Property

Name: | caption-side
New values: | inline-start | inline-end
Computed value: | specified keyword

These two values are added only for implementations that support left and right values for caption-side. The left and right values themselves are defined to be line-relative.

The existing top and bottom values are idiosyncratically redefined as assigning to the block-start and block-end sides of the table, respectively.

The mapping on this property uses the writing mode of the caption’s containing block (that is, the table wrapper box).

### 2.2. Flow-Relative Values for the float and clear Properties

Name: | float, clear
New values: | inline-start | inline-end
Computed value: | specified keyword

The mapping on these properties uses the writing mode of the element’s containing block.

Note: These properties are 1-dimensional in CSS2, but are planned to be expanded to two dimensions, and therefore are given unabbreviated flow-relative keywords.

### 2.3. Flow-Relative Values for the text-align Property

Name: | text-align
New values: | start | end
Computed value: | specified keyword

These values are normatively defined in [css-text-3].

### 2.4. Flow-Relative Values for the resize Property

Name: | resize
New values: | block | inline
Computed value: | specified keyword

## 3. Flow-Relative Page Classifications

In CSS, all pages are classified by user agents as either left pages or right pages. [CSS21] Which page is first in a spread, however, depends on whether the page progression is left-to-right or right-to-left.

To allow control of page breaking to the page that is on the earlier or later side of a spread, rather than to the left or right side of a spread, this module introduces the following additional keywords for the page-break-after and page-break-before properties [CSS21]:

recto
  Equivalent to right in left-to-right page progressions and left in right-to-left page progressions.
verso
  Equivalent to left in left-to-right page progressions and right in right-to-left page progressions.

These values are computed as specified and are further defined in [css-break-3].

Although authors typically place page numbers using physical placements, the contents of headers often follows conventions depending on which page in the spread is earlier. Therefore the following flow-relative page selectors are also added to support flow-relative page selection:

:recto
  Equivalent to ':right' in left-to-right page progressions and ':left' in right-to-left page progressions.
:verso
  Equivalent to ':left' in left-to-right page progressions and ':right' in right-to-left page progressions.

The flow-relative page selectors have specificity equal to the ':left' and ':right' page selectors.

## 4. Flow-Relative Box Model Properties

This specification introduces new CSS properties that are flow-relative equivalents of physical box model properties. Each set of related flow-relative longhand properties and their parallel physical properties form a logical property group. For example, the padding-* properties form a single logical property group, the margin-* properties form a separate logical property group, etc. The type of directional or axis mapping (flow-relative or physical) is called the property’s mapping logic.

Note: Each longhand property is in at most one logical property group.

The specified values of the flow-relative properties are distinct from the specified values of the parallel physical properties, but the flow-relative and physical properties share computed values. Which pairs of properties share computed values depends on the element’s computed values of writing-mode, direction, and text-orientation.

Note: Depending on the element’s own writing mode for mapping every flow-relative property to its physical equivalent simplifies the cascading calculations and gives a straightforward model for authors to reason about. However, it is problematic in many cases, see for example this discussion. Authors may need to use nested elements to get the correct mapping behavior when changing an element’s writing mode from its parent.

A computed value that has flow-relative and physical properties as input is determined by applying the CSS cascade to declarations of both. Overriding is not determined by whether a declaration is flow-relative or physical, but only by the rules of the CSS cascade [css-cascade-3].

Note that this requires implementations to maintain relative order of declarations within a CSS declaration block, which was not previously required for CSS cascading.

For example, given the following rule:

    p {
      margin-inline-start: 1px;
      margin-left: 2px;
      margin-inline-end: 3px;
    }

In a paragraph with computed writing-mode being horizontal-tb and computed direction being ltr, the computed value of margin-left is 2px, since for that writing-mode and direction, margin-inline-start and margin-left share a computed value, and the declaration of margin-left is after the declaration of margin-inline-start. However, if the computed direction were instead rtl, the computed value of margin-left is 3px, since margin-inline-end and margin-left share a computed value, and the declaration of margin-inline-end is after the declaration of margin-left.

[CSSOM] APIs that return computed values (such as `getComputedStyle()`) must return the same value for equivalent pairs of such properties.

There are some open questions on the order of inheritance vs mapping in flow-relative properties and on the interaction of shorthands and logical properties.

### 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties

Name: | block-size, inline-size
Value: | <'width'>
Initial: | auto
Applies to: | Same as height and width
Inherited: | no
Percentages: | As for the corresponding physical property
Computed value: | Same as height, width
Canonical order: | per grammar
Animation type: | by computed value type

These properties correspond to the height and width properties. The mapping depends on the element’s writing-mode.

Name: | min-block-size, min-inline-size
Value: | <'min-width'>
Initial: | 0
Applies to: | same as height and width
Inherited: | no
Percentages: | As for the corresponding physical property
Computed value: | Same as min-height, min-width
Canonical order: | per grammar
Animation type: | by computed value type

These properties correspond to the min-height and min-width properties. The mapping depends on the element’s writing-mode.

Name: | max-block-size, max-inline-size
Value: | <'max-width'>
Initial: | none
Applies to: | same as height and width
Inherited: | no
Percentages: | As for the corresponding physical property
Computed value: | Same as max-height, max-width
Canonical order: | per grammar
Animation type: | by computed value type

These properties correspond to the max-height and max-width properties. The mapping depends on the element’s writing-mode.

### 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands

Name: | margin-block-start, margin-block-end, margin-inline-start, margin-inline-end
Value: | <'margin-top'>
Initial: | 0
Applies to: | Same as margin-top
Inherited: | no
Percentages: | As for the corresponding physical property
Computed value: | Same as corresponding margin-* properties
Canonical order: | per grammar
Animation type: | by computed value type

These properties correspond to the margin-top, margin-bottom, margin-left, and margin-right properties. The mapping depends on the element’s writing-mode, direction, and text-orientation.

Name: | margin-block, margin-inline
Value: | <'margin-top'>{1,2}
Initial: | see individual properties
Applies to: | see individual properties
Inherited: | see individual properties
Percentages: | see individual properties
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

These two shorthand properties set the margin-block-start & margin-block-end and margin-inline-start & margin-inline-end, respectively. The first value represents the start edge style, and the second value represents the end edge style. If only one value is given, it applies to both the start and end edges.

### 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands

The top, left, bottom, right physical properites, their inset-block-start, inset-block-end, inset-inline-start, inset-inline-end flow-relative correspondants, and the inset-block, inset-inline, and inset shorthands, are colectively known as the inset properties.

Name: | inset-block-start, inset-block-end, inset-inline-start, inset-inline-end
Value: | <'top'>
Initial: | auto
Applies to: | positioned elements
Inherited: | no
Percentages: | As for the corresponding physical property
Computed value: | Same as corresponding top/right/bottom/left properties
Canonical order: | per grammar
Animation type: | by computed value type

These properties correspond to the top, bottom, left, and right properties. The mapping depends on the element’s writing-mode, direction, and text-orientation.

Name: | inset-block, inset-inline
Value: | <'top'>{1,2}
Initial: | see individual properties
Applies to: | see individual properties
Inherited: | see individual properties
Percentages: | see individual properties
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

These two shorthand properties set the inset-block-start & inset-block-end and inset-inline-start & inset-inline-end, respectively. The first value represents the start edge style, and the second value represents the end edge style. If only one value is given, it applies to both the start and end edges.

Name: | inset
Value: | <'top'>{1,4}
Initial: | see individual properties
Applies to: | see individual properties
Inherited: | see individual properties
Percentages: | see individual properties
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

This shorthand property sets the top, right, bottom, and left properties. Values are assigned to its sub-properties as for margin.

### 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands

Name: | padding-block-start, padding-block-end, padding-inline-start, padding-inline-end
Value: | <'padding-top'>
Initial: | 0
Applies to: | all elements
Inherited: | no
Percentages: | As for the corresponding physical property
Computed value: | Same as corresponding padding-* properties
Canonical order: | per grammar
Animation type: | by computed value type

These properties correspond to the padding-top, padding-bottom, padding-left, and padding-right properties. The mapping depends on the element’s writing-mode, direction, and text-orientation.

Name: | padding-block, padding-inline
Value: | <'padding-top'>{1,2}
Initial: | see individual properties
Applies to: | see individual properties
Inherited: | see individual properties
Percentages: | see individual properties
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

These two shorthand properties set the padding-block-start & padding-block-end and padding-inline-start & padding-inline-end, respectively. The first value represents the start edge style, and the second value represents the end edge style. If only one value is given, it applies to both the start and end edges.

### 4.5. Flow-relative Borders

#### 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands

Name: | border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width
Value: | <'border-top-width'>
Initial: | medium
Applies to: | all elements
Inherited: | no
Percentages: | n/a
Computed value: | Same as corresponding border-*-width properties
Canonical order: | per grammar
Animation type: | by computed value type

These properties correspond to the border-top-width, border-bottom-width, border-left-width, and border-right-width properties. The mapping depends on the element’s writing-mode, direction, and text-orientation.

Name: | border-block-width, border-inline-width
Value: | <'border-top-width'>{1,2}
Initial: | see individual properties
Applies to: | see individual properties
Inherited: | see individual properties
Percentages: | see individual properties
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

These two shorthand properties set the border-block-start-width & border-block-end-width and border-inline-start-width & border-inline-end-width, respectively. The first value represents the start edge width, and the second value represents the end edge width. If only one value is given, it applies to both the start and end edges.

#### 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands

Name: | border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style
Value: | <'border-top-style'>
Initial: | none
Applies to: | all elements
Inherited: | no
Percentages: | n/a
Computed value: | Same as corresponding border-*-style properties
Canonical order: | per grammar
Animation type: | discrete

These properties correspond to the border-top-style, border-bottom-style, border-left-style, and border-right-style properties. The mapping depends on the element’s writing-mode, direction, and text-orientation.

Name: | border-block-style, border-inline-style
Value: | <'border-top-style'>{1,2}
Initial: | see individual properties
Applies to: | see individual properties
Inherited: | see individual properties
Percentages: | see individual properties
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

These two shorthand properties set the border-block-start-style & border-block-end-style and border-inline-start-style & border-inline-end-style, respectively. The first value represents the start edge style, and the second value represents the end edge style. If only one value is given, it applies to both the start and end edges.

#### 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands

Name: | border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color
Value: | <'border-top-color'>
Initial: | currentcolor
Applies to: | all elements
Inherited: | no
Percentages: | n/a
Computed value: | Same as corresponding border-*-color properties
Canonical order: | per grammar
Animation type: | by computed value type

These properties correspond to the border-top-color, border-bottom-color, border-left-color, and border-right-color properties. The mapping depends on the element’s writing-mode, direction, and text-orientation.

Name: | border-block-color, border-inline-color
Value: | <'border-top-color'>{1,2}
Initial: | see individual properties
Applies to: | see individual properties
Inherited: | see individual properties
Percentages: | see individual properties
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

These two shorthand properties set the border-block-start-color & border-block-end-color and border-inline-start-color & border-inline-end-color, respectively. The first value represents the start edge style, and the second value represents the end edge style. If only one value is given, it applies to both the start and end edges.

#### 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

Name: | border-block-start, border-block-end, border-inline-start, border-inline-end
Value: | <'border-top-width'> || <'border-top-style'> || <color>
Initial: | see individual properties
Applies to: | see individual properties
Inherited: | see individual properties
Percentages: | see individual properties
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

These properties correspond to the border-top, border-bottom, border-left, and border-right properties. The mapping depends on the element’s writing-mode, direction, and text-orientation.

Name: | border-block, border-inline
Value: | <'border-block-start'>
Initial: | see individual properties
Applies to: | see individual properties
Inherited: | see individual properties
Percentages: | see individual properties
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

These two shorthand properties set the border-block-start & border-block-end and border-inline-start & border-inline-end, respectively.

### 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

Name: | border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius
Value: | <'border-top-left-radius'>
Initial: | Same as border-top-left-radius
Applies to: | all elements
Inherited: | no
Percentages: | Same as border-top-left-radius
Computed value: | Same as corresponding physical border-*-radius properties
Canonical order: | per grammar
Animation type: | by computed value type

These properties correspond to the border-top-left-radius, border-bottom-left-radius, border-top-right-radius, and border-bottom-right-radius properties. The mapping depends on the element’s writing-mode, direction, and text-orientation.

### 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands

The shorthand properties for margin, padding, and border set values for physical properties by default. But authors can specify the logical keyword at the beginning of the property value to indicate that the values map to the flow-relative properties instead of the physical ones.

The proposed syntax for this feature is under discussion and is almost guaranteed to change from what is described here. This section remains in the draft to promote discussion of alternatives, to document the affected properties, and to specify the expected impact on the interpretation of whatever syntactic switch is ultimately chosen.

The following [CSS21] shorthand properties accept the logical keyword:

- inset
- margin
- padding
- border-width
- border-style
- border-color
- scroll-padding
- scroll-margin

The syntax for these properties is effectively changed by replacing

    <value-type>{1,4}

with

    logical? <value-type>{1,4}

When the logical keyword is present in the value, the values that follow are assigned to its flow-relative longhands as follows:

- If only one value is set, the value applies to all four flow-relative longhands.
- If two values are set, the first is for block-start and block-end, the second is for inline-start and inline-end.
- If three values are set, the first is for block-start, the second is for inline-start and inline-end, and the third is for block-end.
- If four values are set, they apply to the block-start, inline-start, block-end, and inline-end sides in that order.

In the following example, the two rules are equivalent:

    blockquote {
      margin: logical 1em 2em 3em 4em;
    }
    blockquote {
      margin-block-start:  1em;
      margin-inline-start: 2em;
      margin-block-end:    3em;
      margin-inline-end:   4em;
    }

## 5. Acknowledgements

Cameron McCormack, David Baron, Shinyu Murakami, Tab Atkins

## 6. Changes

Changes since the previous Working Draft include:

- Removing the features for logical background and border-images. (These ideas may be revisited in a future draft.)
- Adding the logical border-radius longhands.

Changes between the earlier Editors Drafts and the 18 May 2017 First Public Working Draft include:

- Making all properties cascade using the writing mode specified on the element, not on its parent.
- Making the ordering of longhands within margin-like shorthands put inline-start before inline-end.
- Adding the *-inline and *-block shorthand forms for margins/borders/padding.
- Renaming the offset-* properties to inset-* and marking an issue for discussion.
- Adding an Introduction section.
- Updating to current terminology of CSS Writing Modes.
- Miscellaneous prose cleanup.

## Conformance

### Document conventions

Conformance requirements are expressed with a combination of descriptive assertions and RFC 2119 terminology. The key words “MUST”, “MUST NOT”, “REQUIRED”, “SHALL”, “SHALL NOT”, “SHOULD”, “SHOULD NOT”, “RECOMMENDED”, “MAY”, and “OPTIONAL” in the normative parts of this document are to be interpreted as described in RFC 2119. However, for readability, these words do not appear in all uppercase letters in this specification.

All of the text of this specification is normative except sections explicitly marked as non-normative, examples, and notes. [RFC2119]

Examples in this specification are introduced with the words “for example” or are set apart from the normative text with `class="example"`, like this:

This is an example of an informative example.

Informative notes begin with the word “Note” and are set apart from the normative text with `class="note"`, like this:

Note, this is an informative note.

Advisements are normative sections styled to evoke special attention and are set apart from other normative text with `<strong class="advisement">`, like this: UAs MUST provide an accessible alternative.

### Conformance classes

Conformance to this specification is defined for three conformance classes:

style sheet
  A CSS style sheet.
renderer
  A UA that interprets the semantics of a style sheet and renders documents that use them.
authoring tool
  A UA that writes a style sheet.

A style sheet is conformant to this specification if all of its statements that use syntax defined in this module are valid according to the generic CSS grammar and the individual grammars of each feature defined in this module.

A renderer is conformant to this specification if, in addition to interpreting the style sheet as defined by the appropriate specifications, it supports all the features defined by this specification by parsing them correctly and rendering the document accordingly. However, the inability of a UA to correctly render a document due to limitations of the device does not make the UA non-conformant. (For example, a UA is not required to render color on a monochrome monitor.)

An authoring tool is conformant to this specification if it writes style sheets that are syntactically correct according to the generic CSS grammar and the individual grammars of each feature in this module, and meet all other conformance requirements of style sheets as described in this module.

### Requirements for Responsible Implementation of CSS

The following sections define several conformance requirements for implementing CSS responsibly, in a way that promotes interoperability in the present and future.

#### Partial Implementations

So that authors can exploit the forward-compatible parsing rules to assign fallback values, CSS renderers must treat as invalid (and ignore as appropriate) any at-rules, properties, property values, keywords, and other syntactic constructs for which they have no usable level of support. In particular, user agents must not selectively ignore unsupported property values and honor supported values in a single multi-value property declaration: if any value is considered invalid (as unsupported values must be), CSS requires that the entire declaration be ignored.

#### Implementations of Unstable and Proprietary Features

To avoid clashes with future stable CSS features, the CSSWG recommends following best practices for the implementation of unstable features and proprietary extensions to CSS.

#### Implementations of CR-level Features

Once a specification reaches the Candidate Recommendation stage, implementers should release an unprefixed implementation of any CR-level feature they can demonstrate to be correctly implemented according to spec, and should avoid exposing a prefixed variant of that feature.

To establish and maintain the interoperability of CSS across implementations, the CSS Working Group requests that non-experimental CSS renderers submit an implementation report (and, if necessary, the testcases used for that implementation report) to the W3C before releasing an unprefixed implementation of any CSS features. Testcases submitted to W3C are subject to review and correction by the CSS Working Group.

Further information on submitting testcases and implementation reports can be found from on the CSS Working Group’s website at http://www.w3.org/Style/CSS/Test/. Questions should be directed to the public-css-testsuite@w3.org mailing list.

## Index

### Terms defined by this specification

- block-size, in §4.1
- border-block, in §4.5.4
- border-block-color, in §4.5.3
- border-block-end, in §4.5.4
- border-block-end-color, in §4.5.3
- border-block-end-style, in §4.5.2
- border-block-end-width, in §4.5.1
- border-block-start, in §4.5.4
- border-block-start-color, in §4.5.3
- border-block-start-style, in §4.5.2
- border-block-start-width, in §4.5.1
- border-block-style, in §4.5.2
- border-block-width, in §4.5.1
- border-end-end-radius, in §4.6
- border-end-start-radius, in §4.6
- border-inline, in §4.5.4
- border-inline-color, in §4.5.3
- border-inline-end, in §4.5.4
- border-inline-end-color, in §4.5.3
- border-inline-end-style, in §4.5.2
- border-inline-end-width, in §4.5.1
- border-inline-start, in §4.5.4
- border-inline-start-color, in §4.5.3
- border-inline-start-style, in §4.5.2
- border-inline-start-width, in §4.5.1
- border-inline-style, in §4.5.2
- border-inline-width, in §4.5.1
- border-start-end-radius, in §4.6
- border-start-start-radius, in §4.6
- inline-size, in §4.1
- inset, in §4.3
- inset-block, in §4.3
- inset-block-end, in §4.3
- inset-block-start, in §4.3
- inset-inline, in §4.3
- inset-inline-end, in §4.3
- inset-inline-start, in §4.3
- inset properties, in §4.3
- logical, in §4.7
- logical property group, in §4
- mapping logic, in §4
- margin-block, in §4.2
- margin-block-end, in §4.2
- margin-block-start, in §4.2
- margin-inline, in §4.2
- margin-inline-end, in §4.2
- margin-inline-start, in §4.2
- max-block-size, in §4.1
- max-inline-size, in §4.1
- min-block-size, in §4.1
- min-inline-size, in §4.1
- padding-block, in §4.4
- padding-block-end, in §4.4
- padding-block-start, in §4.4
- padding-inline, in §4.4
- padding-inline-end, in §4.4
- padding-inline-start, in §4.4
- :recto, in §3
- recto, in §3
- :verso, in §3
- verso, in §3

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-bottom Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-bottom-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-bottom-left-radius Referenced in:

- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-bottom-right-radius Referenced in:

- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-bottom-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-bottom-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-color Referenced in:

- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands (2)

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-left Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-left-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-left-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-left-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-radius Referenced in:

- 6. Changes

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-right Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-right-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-right-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-right-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-style Referenced in:

- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands (2)

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-top Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-top-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands (2) (3)

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-top-left-radius Referenced in:

- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties (2) (3) (4)

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-top-right-radius Referenced in:

- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-top-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands (2) (3)
- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-top-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands (2) (3)
- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

https://drafts.csswg.org/css-backgrounds-3/#propdef-border-width Referenced in:

- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands (2)

https://drafts.csswg.org/css-box-3/#propdef-margin Referenced in:

- 1. Introduction
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands
- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands (2)
- 6. Changes

https://drafts.csswg.org/css-box-3/#propdef-margin-bottom Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands

https://drafts.csswg.org/css-box-3/#propdef-margin-left Referenced in:

- 4. Flow-Relative Box Model Properties (2) (3) (4) (5) (6)
- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands

https://drafts.csswg.org/css-box-3/#propdef-margin-right Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands

https://drafts.csswg.org/css-box-3/#propdef-margin-top Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands (2) (3) (4)

https://drafts.csswg.org/css-box-3/#propdef-padding Referenced in:

- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands (2)

https://drafts.csswg.org/css-box-3/#propdef-padding-bottom Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands

https://drafts.csswg.org/css-box-3/#propdef-padding-left Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands

https://drafts.csswg.org/css-box-3/#propdef-padding-right Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands

https://drafts.csswg.org/css-box-3/#propdef-padding-top Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands (2) (3)

https://drafts.csswg.org/css-cascade-4/#computed-value Referenced in:

- 1. Introduction

https://drafts.csswg.org/css-cascade-4/#longhand Referenced in:

- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands
- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands

https://drafts.csswg.org/css-cascade-4/#shorthand-property Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2)
- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands
- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands
- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands
- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands
- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

https://drafts.csswg.org/css-cascade-4/#specified-value Referenced in:

- 4. Flow-Relative Box Model Properties

https://drafts.csswg.org/css-cascade-4/#longhand Referenced in:

- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands
- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands

https://drafts.csswg.org/css-cascade-4/#used-value Referenced in:

- 1. Introduction (2)

https://drafts.csswg.org/css-color-3/#valuea-def-color Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

https://drafts.csswg.org/css-display-3/#containing-block Referenced in:

- 2.1. Logical Values for the caption-side Property
- 2.2. Flow-Relative Values for the float and clear Properties

https://drafts.csswg.org/css-position-3/#propdef-bottom Referenced in:

- 2. Flow-Relative Values: block-start, block-end, inline-start, inline-end
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2) (3) (4)

https://drafts.csswg.org/css-position-3/#propdef-left Referenced in:

- 2. Flow-Relative Values: block-start, block-end, inline-start, inline-end
- 3. Flow-Relative Page Classifications (2)
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2) (3) (4)

https://drafts.csswg.org/css-position-3/#propdef-right Referenced in:

- 2. Flow-Relative Values: block-start, block-end, inline-start, inline-end
- 3. Flow-Relative Page Classifications (2)
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2) (3) (4)

https://drafts.csswg.org/css-position-3/#propdef-top Referenced in:

- 2. Flow-Relative Values: block-start, block-end, inline-start, inline-end
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2) (3) (4) (5) (6) (7)

https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin Referenced in:

- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands

https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding Referenced in:

- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands

https://drafts.csswg.org/css-tables-3/#table-wrapper-box Referenced in:

- 2.1. Logical Values for the caption-side Property

https://drafts.csswg.org/css-text-3/#propdef-text-align Referenced in:

- 2.3. Flow-Relative Values for the text-align Property (2)

https://drafts.csswg.org/css-ui-4/#propdef-resize Referenced in:

- 2.4. Flow-Relative Values for the resize Property (2)

https://drafts.csswg.org/css-values-4/#mult-opt Referenced in:

- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands

https://drafts.csswg.org/css-values-4/#mult-num-range Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2)
- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands
- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands
- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands
- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands
- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands (2)

https://drafts.csswg.org/css-values-4/#comb-one Referenced in:

- 2.1. Logical Values for the caption-side Property
- 2.2. Flow-Relative Values for the float and clear Properties
- 2.3. Flow-Relative Values for the text-align Property
- 2.4. Flow-Relative Values for the resize Property

https://drafts.csswg.org/css-values-4/#comb-any Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands (2)

https://drafts.csswg.org/css-writing-modes-3/#propdef-direction Referenced in:

- 1. Introduction (2)
- 4. Flow-Relative Box Model Properties (2) (3) (4)
- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands
- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands
- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands
- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands
- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands
- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands
- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

https://drafts.csswg.org/css-writing-modes-3/#end Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands (2)
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2)
- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands (2)
- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands (2)
- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands (2)
- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands (2)

https://drafts.csswg.org/css-writing-modes-3/#start Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands (2)
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2)
- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands (2)
- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands (2)
- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands (2)
- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands (2)

https://drafts.csswg.org/css-writing-modes-4/#block-end Referenced in:

- 2.1. Logical Values for the caption-side Property

https://drafts.csswg.org/css-writing-modes-4/#block-start Referenced in:

- 2.1. Logical Values for the caption-side Property

https://drafts.csswg.org/css-writing-modes-4/#flow-relative Referenced in:

- 1. Introduction (2)
- 2. Flow-Relative Values: block-start, block-end, inline-start, inline-end
- 2.2. Flow-Relative Values for the float and clear Properties
- 4. Flow-Relative Box Model Properties (2) (3) (4)

https://drafts.csswg.org/css-writing-modes-4/#valdef-writing-mode-horizontal-tb Referenced in:

- 4. Flow-Relative Box Model Properties

https://drafts.csswg.org/css-writing-modes-4/#line-relative Referenced in:

- 2.1. Logical Values for the caption-side Property

https://drafts.csswg.org/css-writing-modes-4/#valdef-direction-ltr Referenced in:

- 4. Flow-Relative Box Model Properties

https://drafts.csswg.org/css-writing-modes-4/#physical Referenced in:

- 4. Flow-Relative Box Model Properties (2) (3)

https://drafts.csswg.org/css-writing-modes-4/#valdef-direction-rtl Referenced in:

- 4. Flow-Relative Box Model Properties

https://drafts.csswg.org/css-writing-modes-4/#propdef-text-orientation Referenced in:

- 1. Introduction (2)
- 4. Flow-Relative Box Model Properties
- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands
- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands
- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands
- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands
- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands
- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands
- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

https://drafts.csswg.org/css-writing-modes-4/#writing-mode Referenced in:

- 1. Introduction
- 2.1. Logical Values for the caption-side Property
- 2.2. Flow-Relative Values for the float and clear Properties
- 4. Flow-Relative Box Model Properties (2)
- 6. Changes

https://drafts.csswg.org/css-writing-modes-4/#propdef-writing-mode Referenced in:

- 1. Introduction (2)
- 4. Flow-Relative Box Model Properties (2) (3)
- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties (2) (3)
- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands
- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands
- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands
- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands
- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands
- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands
- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands
- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

https://drafts.csswg.org/css2/tables.html#propdef-caption-side Referenced in:

- 2.1. Logical Values for the caption-side Property (2) (3)

https://drafts.csswg.org/css2/visuren.html#propdef-clear Referenced in:

- 2.2. Flow-Relative Values for the float and clear Properties (2)

https://drafts.csswg.org/css2/visuren.html#propdef-float Referenced in:

- 2.2. Flow-Relative Values for the float and clear Properties (2)

https://drafts.csswg.org/css2/visudet.html#propdef-height Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties (2) (3) (4) (5)

https://drafts.csswg.org/css2/visudet.html#propdef-max-height Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties (2)

https://drafts.csswg.org/css2/visudet.html#propdef-max-width Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties (2) (3)

https://drafts.csswg.org/css2/visudet.html#propdef-min-height Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties (2)

https://drafts.csswg.org/css2/visudet.html#propdef-min-width Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties (2) (3)

https://drafts.csswg.org/css2/page.html#propdef-page-break-after Referenced in:

- 3. Flow-Relative Page Classifications

https://drafts.csswg.org/css2/page.html#propdef-page-break-before Referenced in:

- 3. Flow-Relative Page Classifications

https://drafts.csswg.org/css2/visudet.html#propdef-width Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties (2) (3) (4) (5) (6)

### Terms defined by reference

- [css-backgrounds-3] defines the following terms:
  - border-bottom
  - border-bottom-color
  - border-bottom-left-radius
  - border-bottom-right-radius
  - border-bottom-style
  - border-bottom-width
  - border-color
  - border-left
  - border-left-color
  - border-left-style
  - border-left-width
  - border-radius
  - border-right
  - border-right-color
  - border-right-style
  - border-right-width
  - border-style
  - border-top
  - border-top-color
  - border-top-left-radius
  - border-top-right-radius
  - border-top-style
  - border-top-width
  - border-width
- [css-box-3] defines the following terms:
  - margin
  - margin-bottom
  - margin-left
  - margin-right
  - margin-top
  - padding
  - padding-bottom
  - padding-left
  - padding-right
  - padding-top
- [css-cascade-4] defines the following terms:
  - computed value
  - longhand
  - shorthand property
  - specified value
  - sub-property
  - used value
- [css-color-3] defines the following terms:
  - <color>
- [css-display-3] defines the following terms:
  - containing block
- [css-position-3] defines the following terms:
  - bottom
  - left
  - right
  - top
- [css-scroll-snap-1] defines the following terms:
  - scroll-margin
  - scroll-padding
- [css-tables-3] defines the following terms:
  - table wrapper box
- [css-text-3] defines the following terms:
  - text-align
- [css-ui-4] defines the following terms:
  - resize
- [css-values-4] defines the following terms:
  - ?
  - {a,b}
  - |
  - ||
- [css-writing-modes-3] defines the following terms:
  - direction
  - end
  - start
- [css-writing-modes-4] defines the following terms:
  - block-end
  - block-start
  - flow-relative
  - horizontal-tb
  - line-relative
  - ltr
  - physical
  - rtl
  - text-orientation
  - writing mode
  - writing-mode
- [CSS21] defines the following terms:
  - caption-side
  - clear
  - float
  - height
  - max-height
  - max-width
  - min-height
  - min-width
  - page-break-after
  - page-break-before
  - width

## References

### Normative References

[CSS-BACKGROUNDS-3]
  Bert Bos; Elika Etemad; Brad Kemper. CSS Backgrounds and Borders Module Level 3. 17 October 2017. CR. URL: https://www.w3.org/TR/css-backgrounds-3/
[CSS-BOX-3]
  Elika Etemad. CSS Box Model Module Level 3. 18 December 2018. WD. URL: https://www.w3.org/TR/css-box-3/
[CSS-BREAK-3]
  Rossen Atanassov; Elika Etemad. CSS Fragmentation Module Level 3. 4 December 2018. CR. URL: https://www.w3.org/TR/css-break-3/
[CSS-CASCADE-3]
  Elika Etemad; Tab Atkins Jr.. CSS Cascading and Inheritance Level 3. 28 August 2018. CR. URL: https://www.w3.org/TR/css-cascade-3/
[CSS-CASCADE-4]
  Elika Etemad; Tab Atkins Jr.. CSS Cascading and Inheritance Level 4. 28 August 2018. CR. URL: https://www.w3.org/TR/css-cascade-4/
[CSS-COLOR-3]
  Tantek Çelik; Chris Lilley; David Baron. CSS Color Module Level 3. 19 June 2018. REC. URL: https://www.w3.org/TR/css-color-3/
[CSS-DISPLAY-3]
  Tab Atkins Jr.; Elika Etemad. CSS Display Module Level 3. 28 August 2018. CR. URL: https://www.w3.org/TR/css-display-3/
[CSS-POSITION-3]
  Rossen Atanassov; Arron Eicholz. CSS Positioned Layout Module Level 3. 17 May 2016. WD. URL: https://www.w3.org/TR/css-position-3/
[CSS-SCROLL-SNAP-1]
  Matt Rakow; et al. CSS Scroll Snap Module Level 1. 19 March 2019. CR. URL: https://www.w3.org/TR/css-scroll-snap-1/
[CSS-TABLES-3]
  Greg Whitworth. CSS Table Module Level 3. 7 March 2017. WD. URL: https://www.w3.org/TR/css-tables-3/
[CSS-TEXT-3]
  Elika Etemad; Koji Ishii; Florian Rivoal. CSS Text Module Level 3. 12 December 2018. WD. URL: https://www.w3.org/TR/css-text-3/
[CSS-UI-4]
  Florian Rivoal. CSS Basic User Interface Module Level 4. 22 December 2017. WD. URL: https://www.w3.org/TR/css-ui-4/
[CSS-VALUES-4]
  Tab Atkins Jr.; Elika Etemad. CSS Values and Units Module Level 4. 31 January 2019. WD. URL: https://www.w3.org/TR/css-values-4/
[CSS-WRITING-MODES-3]
  Elika Etemad; Koji Ishii. CSS Writing Modes Level 3. 24 May 2018. CR. URL: https://www.w3.org/TR/css-writing-modes-3/
[CSS-WRITING-MODES-4]
  Elika Etemad; Koji Ishii. CSS Writing Modes Level 4. 24 May 2018. CR. URL: https://www.w3.org/TR/css-writing-modes-4/
[CSS21]
  Bert Bos; et al. Cascading Style Sheets Level 2 Revision 1 (CSS 2.1) Specification. 7 June 2011. REC. URL: https://www.w3.org/TR/CSS2/
[CSSOM]
  Simon Pieters; Glenn Adams. CSS Object Model (CSSOM). 17 March 2016. WD. URL: https://www.w3.org/TR/cssom-1/
[RFC2119]
  S. Bradner. Key words for use in RFCs to Indicate Requirement Levels. March 1997. Best Current Practice. URL: https://tools.ietf.org/html/rfc2119

## Property Index

Name | Value | Initial | Applies to | Inh. | %ages | Animation type | Canonical order | Computed value
--- | --- | --- | --- | --- | --- | --- | --- | ---
block-size | <'width'> | auto | Same as height and width | no | As for the corresponding physical property | by computed value type | per grammar | Same as height, width
border-block | <'border-block-start'> | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-block-color | <'border-top-color'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-block-end | <'border-top-width'> || <'border-top-style'> || <color> | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-block-end-color | <'border-top-color'> | currentcolor | all elements | no | n/a | by computed value type | per grammar | Same as corresponding border-*-color properties
border-block-end-style | <'border-top-style'> | none | all elements | no | n/a | discrete | per grammar | Same as corresponding border-*-style properties
border-block-end-width | <'border-top-width'> | medium | all elements | no | n/a | by computed value type | per grammar | Same as corresponding border-*-width properties
border-block-start | <'border-top-width'> || <'border-top-style'> || <color> | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-block-start-color | <'border-top-color'> | currentcolor | all elements | no | n/a | by computed value type | per grammar | Same as corresponding border-*-color properties
border-block-start-style | <'border-top-style'> | none | all elements | no | n/a | discrete | per grammar | Same as corresponding border-*-style properties
border-block-start-width | <'border-top-width'> | medium | all elements | no | n/a | by computed value type | per grammar | Same as corresponding border-*-width properties
border-block-style | <'border-top-style'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-block-width | <'border-top-width'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-end-end-radius | <'border-top-left-radius'> | Same as border-top-left-radius | all elements | no | Same as border-top-left-radius | by computed value type | per grammar | Same as corresponding physical border-*-radius properties
border-end-start-radius | <'border-top-left-radius'> | Same as border-top-left-radius | all elements | no | Same as border-top-left-radius | by computed value type | per grammar | Same as corresponding physical border-*-radius properties
border-inline | <'border-block-start'> | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-inline-color | <'border-top-color'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-inline-end | <'border-top-width'> || <'border-top-style'> || <color> | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-inline-end-color | <'border-top-color'> | currentcolor | all elements | no | n/a | by computed value type | per grammar | Same as corresponding border-*-color properties
border-inline-end-style | <'border-top-style'> | none | all elements | no | n/a | discrete | per grammar | Same as corresponding border-*-style properties
border-inline-end-width | <'border-top-width'> | medium | all elements | no | n/a | by computed value type | per grammar | Same as corresponding border-*-width properties
border-inline-start | <'border-top-width'> || <'border-top-style'> || <color> | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-inline-start-color | <'border-top-color'> | currentcolor | all elements | no | n/a | by computed value type | per grammar | Same as corresponding border-*-color properties
border-inline-start-style | <'border-top-style'> | none | all elements | no | n/a | discrete | per grammar | Same as corresponding border-*-style properties
border-inline-start-width | <'border-top-width'> | medium | all elements | no | n/a | by computed value type | per grammar | Same as corresponding border-*-width properties
border-inline-style | <'border-top-style'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-inline-width | <'border-top-width'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
border-start-end-radius | <'border-top-left-radius'> | Same as border-top-left-radius | all elements | no | Same as border-top-left-radius | by computed value type | per grammar | Same as corresponding physical border-*-radius properties
border-start-start-radius | <'border-top-left-radius'> | Same as border-top-left-radius | all elements | no | Same as border-top-left-radius | by computed value type | per grammar | Same as corresponding physical border-*-radius properties
inline-size | <'width'> | auto | Same as height and width | no | As for the corresponding physical property | by computed value type | per grammar | Same as height, width
inset | <'top'>{1,4} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
inset-block | <'top'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
inset-block-end | <'top'> | auto | positioned elements | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding top/right/bottom/left properties
inset-block-start | <'top'> | auto | positioned elements | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding top/right/bottom/left properties
inset-inline | <'top'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
inset-inline-end | <'top'> | auto | positioned elements | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding top/right/bottom/left properties
inset-inline-start | <'top'> | auto | positioned elements | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding top/right/bottom/left properties
margin-block | <'margin-top'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
margin-block-end | <'margin-top'> | 0 | Same as margin-top | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding margin-* properties
margin-block-start | <'margin-top'> | 0 | Same as margin-top | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding margin-* properties
margin-inline | <'margin-top'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
margin-inline-end | <'margin-top'> | 0 | Same as margin-top | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding margin-* properties
margin-inline-start | <'margin-top'> | 0 | Same as margin-top | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding margin-* properties
max-block-size | <'max-width'> | none | same as height and width | no | As for the corresponding physical property | by computed value type | per grammar | Same as max-height, max-width
max-inline-size | <'max-width'> | none | same as height and width | no | As for the corresponding physical property | by computed value type | per grammar | Same as max-height, max-width
min-block-size | <'min-width'> | 0 | same as height and width | no | As for the corresponding physical property | by computed value type | per grammar | Same as min-height, min-width
min-inline-size | <'min-width'> | 0 | same as height and width | no | As for the corresponding physical property | by computed value type | per grammar | Same as min-height, min-width
padding-block | <'padding-top'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
padding-block-end | <'padding-top'> | 0 | all elements | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding padding-* properties
padding-block-start | <'padding-top'> | 0 | all elements | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding padding-* properties
padding-inline | <'padding-top'>{1,2} | see individual properties | see individual properties | see individual properties | see individual properties | see individual properties | per grammar | see individual properties
padding-inline-end | <'padding-top'> | 0 | all elements | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding padding-* properties
padding-inline-start | <'padding-top'> | 0 | all elements | no | As for the corresponding physical property | by computed value type | per grammar | Same as corresponding padding-* properties

## Issues Index

Things That Are Unstable Since implementation of parts of this module is effectively required for shipping an implementation of CSS Writing Modes on the Web (in order to correctly implement the default HTML styles), the CSSWG resolved that the requisite features in § 2 Flow-Relative Values: block-start, block-end, inline-start, inline-end and § 4 Flow-Relative Box Model Properties are approved for shipping. (See FPWD announcement for additional background.)

However, there are a few significant open issues:

- The logical keyword on shorthands, because the name of the keyword may change or it may be replaced by some other syntactic marker. (This feature will be deferred from this level for further development if there is no clearly satisfactory mechanism proposed, see Issue 1282.)
- Whether flow-relative longhands inherit from their namesake on the parent, or are mapped to a physical property and inherit from that property. (See Issue 3029.)
- Whether shorthands like margin expand to both sets of longhands, or only the ones that were set. (See Issue 3030.)

Comments, suggestions, and use cases are welcome on these issues. Please file them in GitHub, tweet them to @csswg, or send them to www-style@w3.org. ↵
There are some open questions on the order of inheritance vs mapping in flow-relative properties and on the interaction of shorthands and logical properties. ↵
The proposed syntax for this feature is under discussion and is almost guaranteed to change from what is described here. This section remains in the draft to promote discussion of alternatives, to document the affected properties, and to specify the expected impact on the interpretation of whatever syntactic switch is ultimately chosen. ↵
#logical-property-group Referenced in:

- 4. Flow-Relative Box Model Properties (2) (3)

#propdef-block-size Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties

#propdef-inline-size Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties

#propdef-min-block-size Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties

#propdef-min-inline-size Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties

#propdef-max-block-size Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties

#propdef-max-inline-size Referenced in:

- 4.1. Logical Height and Logical Width: the block-size/inline-size, min-block-size/min-inline-size, and max-block-size/max-inline-size properties

#propdef-margin-block-start Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands (2)

#propdef-margin-block-end Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands (2)

#propdef-margin-inline-start Referenced in:

- 4. Flow-Relative Box Model Properties (2)
- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands (2)

#propdef-margin-inline-end Referenced in:

- 4. Flow-Relative Box Model Properties (2)
- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands (2)

#propdef-margin-block Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands

#propdef-margin-inline Referenced in:

- 4.2. Flow-relative Margins: the margin-block-start, margin-block-end, margin-inline-start, margin-inline-end properties and margin-block and margin-inline shorthands

#propdef-inset-block-start Referenced in:

- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2) (3)

#propdef-inset-block-end Referenced in:

- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2) (3)

#propdef-inset-inline-start Referenced in:

- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2) (3)

#propdef-inset-inline-end Referenced in:

- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2) (3)

#propdef-inset-block Referenced in:

- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2)

#propdef-inset-inline Referenced in:

- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2)

#propdef-inset Referenced in:

- 4.3. Flow-relative Offsets: the inset-block-start, inset-block-end, inset-inline-start, inset-inline-end properties and inset-block, inset-inline, and inset shorthands (2)
- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands

#propdef-padding-block-start Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands (2)

#propdef-padding-block-end Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands (2)

#propdef-padding-inline-start Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands (2)

#propdef-padding-inline-end Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands (2)

#propdef-padding-block Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands

#propdef-padding-inline Referenced in:

- 4.4. Flow-relative Padding: the padding-block-start, padding-block-end, padding-inline-start, padding-inline-end properties and padding-block and padding-inline shorthands

#propdef-border-block-start-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands (2)

#propdef-border-block-end-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands (2)

#propdef-border-inline-start-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands (2)

#propdef-border-inline-end-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands (2)

#propdef-border-block-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands

#propdef-border-inline-width Referenced in:

- 4.5.1. Flow-relative Border Widths: the border-block-start-width, border-block-end-width, border-inline-start-width, border-inline-end-width properties and border-block-width and border-inline-width shorthands

#propdef-border-block-start-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands (2)

#propdef-border-block-end-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands (2)

#propdef-border-inline-start-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands (2)

#propdef-border-inline-end-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands (2)

#propdef-border-block-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands

#propdef-border-inline-style Referenced in:

- 4.5.2. Flow-relative Border Styles: the border-block-start-style, border-block-end-style, border-inline-start-style, border-inline-end-style properties and border-block-style and border-inline-style shorthands

#propdef-border-block-start-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands (2)

#propdef-border-block-end-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands (2)

#propdef-border-inline-start-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands (2)

#propdef-border-inline-end-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands (2)

#propdef-border-block-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands

#propdef-border-inline-color Referenced in:

- 4.5.3. Flow-relative Border Colors: the border-block-start-color, border-block-end-color, border-inline-start-color, border-inline-end-color properties and border-block-color and border-inline-color shorthands

#propdef-border-block-start Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands (2) (3)

#propdef-border-block-end Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands (2)

#propdef-border-inline-start Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands (2)

#propdef-border-inline-end Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands (2)

#propdef-border-block Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

#propdef-border-inline Referenced in:

- 4.5.4. Flow-relative Border Shorthands: the border-block-start, border-block-end, border-inline-start, border-inline-end properties and border-block and border-inline shorthands

#propdef-border-start-start-radius Referenced in:

- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

#propdef-border-start-end-radius Referenced in:

- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

#propdef-border-end-start-radius Referenced in:

- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

#propdef-border-end-end-radius Referenced in:

- 4.6. Flow-relative Corner Rounding: the border-start-start-radius, border-start-end-radius, border-end-start-radius, border-end-end-radius properties

#valdef-margin-logical Referenced in:

- 4.7. Four-Directional Shorthand Properties: the margin, padding, border-width, border-style, and border-color shorthands (2)